@@ -1,26 +1,24 @@
 # -*- coding: utf_8 -*-
 """Semantic Grep Helpers."""
+import json
+import platform
 import multiprocessing
 from io import StringIO
-import json
-
-
-from semgrep.constants import OutputFormat
-from semgrep.output import (
-    OutputHandler,
-    OutputSettings,
-)
-from semgrep import semgrep_main, util
-
-try:
-    CPU_COUNT = multiprocessing.cpu_count()
-except NotImplementedError:
-    CPU_COUNT = 1  # CPU count is not implemented on Windows
 
 
 def invoke_semgrep(paths, scan_rules, **kwargs):
     """Call Semgrep."""
+    if platform.system() == 'Windows':
+        return None
+    from semgrep import semgrep_main, util
+    from semgrep.constants import OutputFormat
+    from semgrep.output import OutputHandler, OutputSettings
+    try:
+        cpu_count = multiprocessing.cpu_count()
+    except NotImplementedError:
+        cpu_count = 1  # CPU count is not implemented on Windows
     util.set_flags(False, True, False)  # Verbose, Quiet, Force_color
+
     io_capture = StringIO()
     output_handler = OutputHandler(
         OutputSettings(
@@ -34,7 +32,7 @@ def invoke_semgrep(paths, scan_rules, **kwargs):
     semgrep_main.main(
         output_handler=output_handler,
         target=[pt.as_posix() for pt in paths],
-        jobs=CPU_COUNT,
+        jobs=cpu_count,
         pattern=None,
         lang=None,
         config=scan_rules,
